=============================
Django Categories v |version|
=============================

Django Categories grew out of our need to provide a basic hierarchical taxonomy management system that multiple applications could use independently or in concert.

As a news site, our stories, photos, and other content get divided into "sections" and we wanted all the apps to use the same set of sections. As our needs grew, the Django Categories grew in the functionality it gave to category handling within web pages.


Contents
========

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   getting_started
   user_guide/index
   reference/index
   api/index
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
